@@ -998,7 +998,7 @@ class CloudifyWorkflowContext(
                 storage = self.internal.handler.storage
                 raw_nodes = storage.get_nodes()
                 raw_node_instances = storage.get_node_instances()
-            else:
+            elif self.deployment.id:
                 rest = get_rest_client()
                 raw_nodes = rest.nodes.list(
                     deployment_id=self.deployment.id,
@@ -1007,6 +1007,11 @@ class CloudifyWorkflowContext(
                 raw_node_instances = rest.node_instances.list(
                     deployment_id=self.deployment.id,
                     _get_all_results=True)
+            else:
+                # no deployment means no nodes
+                # this happens in eg. blueprint-upload
+                raw_nodes = []
+                raw_node_instances = []
 
             WorkflowNodesAndInstancesContainer.__init__(self, self, raw_nodes,
                                                         raw_node_instances)
@@ -1100,7 +1105,7 @@ class CloudifyWorkflowContextInternal(object):
         retry_interval = workflows.get(
             'task_retry_interval',
             self.workflow_context._task_retry_interval)
-        return dict(total_retries=total_retries,
+        return dict(total_retries=int(total_retries),
                     retry_interval=retry_interval)
 
     def get_subgraph_task_configuration(self):
@@ -1417,6 +1422,7 @@ class RemoteContextHandler(CloudifyWorkflowContextHandler):
         return {'local': False,
                 'bypass_maintenance': utils.get_is_bypass_maintenance(),
                 'rest_token': utils.get_rest_token(),
+                'workflow_parameters': utils.get_workflow_parameters(),
                 'execution_token': utils.get_execution_token(),
                 'execution_creator_username':
                     utils.get_execution_creator_username()}
